@@ -6,11 +6,16 @@
 
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
+
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in
      the documentation and/or other materials provided with the
      distribution.
 
+   * Neither the name of the copyright holders nor the names of
+     contributors may be used to endorse or promote products derived
+     from this software without specific prior written permission.
+
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -23,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom128.h,v 1.10.2.2 2003/10/20 19:02:36 troth Exp $ */
+/* $Id: iom128.h,v 1.14 2004/12/30 18:45:13 arcanum Exp $ */
 
 /* avr/iom128.h - defines for ATmega128 
 
@@ -363,9 +368,12 @@
 #define SIG_OUTPUT_COMPARE0     _VECTOR(15)
 #define SIG_OVERFLOW0           _VECTOR(16)
 #define SIG_SPI                 _VECTOR(17)
-#define SIG_UART0_RECV          _VECTOR(18)
-#define SIG_UART0_DATA          _VECTOR(19)
-#define SIG_UART0_TRANS         _VECTOR(20)
+#define SIG_USART0_RECV         _VECTOR(18)
+#define SIG_UART0_RECV          _VECTOR(18) /* Keep for compatibility */
+#define SIG_USART0_DATA         _VECTOR(19)
+#define SIG_UART0_DATA          _VECTOR(19) /* Keep for compatibility */
+#define SIG_USART0_TRANS        _VECTOR(20)
+#define SIG_UART0_TRANS         _VECTOR(20) /* Keep for compatibility */
 #define SIG_ADC                 _VECTOR(21)
 #define SIG_EEPROM_READY        _VECTOR(22)
 #define SIG_COMPARATOR          _VECTOR(23)
@@ -375,9 +383,12 @@
 #define SIG_OUTPUT_COMPARE3B    _VECTOR(27)
 #define SIG_OUTPUT_COMPARE3C    _VECTOR(28)
 #define SIG_OVERFLOW3           _VECTOR(29)
-#define SIG_UART1_RECV          _VECTOR(30)
-#define SIG_UART1_DATA          _VECTOR(31)
-#define SIG_UART1_TRANS         _VECTOR(32)
+#define SIG_USART1_RECV         _VECTOR(30)
+#define SIG_UART1_RECV          _VECTOR(30) /* Keep for compatibility */
+#define SIG_USART1_DATA         _VECTOR(31)
+#define SIG_UART1_DATA          _VECTOR(31) /* Keep for compatibility */
+#define SIG_USART1_TRANS        _VECTOR(32)
+#define SIG_UART1_TRANS         _VECTOR(32) /* Keep for compatibility */
 #define SIG_2WIRE_SERIAL        _VECTOR(33)
 #define SIG_SPM_READY           _VECTOR(34)
 
