@@ -1,4 +1,4 @@
-/* Copyright (c) 2002, 2003, 2004
+/* Copyright (c) 2002, 2003, 2004 
    Juergen Schilling <juergen.schilling@honeywell.com>
    All rights reserved.
 
@@ -7,11 +7,16 @@
 
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
+
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in
      the documentation and/or other materials provided with the
      distribution.
 
+   * Neither the name of the copyright holders nor the names of
+     contributors may be used to endorse or promote products derived
+     from this software without specific prior written permission.
+
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -24,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom169.h,v 1.13.2.3 2004/10/18 16:42:53 arcanum Exp $ */
+/* $Id: iom169.h,v 1.17 2004/12/30 18:55:31 arcanum Exp $ */
 
 /* iom169.h - definitions for ATmega169 */
 
@@ -167,6 +172,13 @@
 /* Clock Prescale Register */
 #define CLKPR  _SFR_MEM8(0x61)
 
+#define PRR    _SFR_MEM8(0x64)
+#define PRADC       0
+#define PRUSART0    1
+#define PRSPI       2
+#define PRTIM1      3
+#define PRLCD       4
+
 /* Oscillator Calibration Register */
 #define OSCCAL _SFR_MEM8(0x66)
 
@@ -234,19 +246,13 @@
 
 /* Timer/Counter1 Output Compare Register A */
 #define OCR1A  _SFR_MEM16(0x88)
-#define OCRA1  OCR1A            /* For compatibility with previous releases. */
 #define OCR1AL _SFR_MEM8(0x88)
-#define OCRA1L OCR1AL           /* For compatibility with previous releases. */
 #define OCR1AH _SFR_MEM8(0x89)
-#define OCRA1H OCR1AH           /* For compatibility with previous releases. */
 
 /* Timer/Counter1 Output Compare Registare B */
 #define OCR1B  _SFR_MEM16(0x8A)
-#define OCRB1  OCR1B            /* For compatibility with previous releases. */
 #define OCR1BL _SFR_MEM8(0x8A)
-#define OCRB1L OCR1BL           /* For compatibility with previous releases. */
 #define OCR1BH _SFR_MEM8(0x8B)
-#define OCRB1H OCR1BH           /* For compatibility with previous releases. */
 
 /* Timer/Counter2 Control Register A */
 #define TCCR2A _SFR_MEM8(0xB0)
@@ -271,29 +277,20 @@
 
 /* USART0 Control and Status Register A */
 #define UCSRA  _SFR_MEM8(0xC0)
-#define UCSR0A UCSRA            /* For compatibility with previous releases. */
 
 /* USART0 Control and Status Register B */
 #define UCSRB  _SFR_MEM8(0xC1)
-#define UCSR0B UCSRB            /* For compatibility with previous releases. */
 
 /* USART0 Control and Status Register C */
 #define UCSRC  _SFR_MEM8(0xC2)
-#define UCSR0C UCSRC            /* For compatibility with previous releases. */
 
 /* USART0 Baud Rate Register */
 #define UBRR   _SFR_MEM16(0xC4)
 #define UBRRL  _SFR_MEM8(0xC4)
 #define UBRRH  _SFR_MEM8(0xC5)
 
-/* For compatibility with previous releases. */
-#define UBRR0  UBRR
-#define UBRR0L UBRRL
-#define UBRR0H UBRRH
-
 /* USART0 I/O Data Register */
 #define UDR    _SFR_MEM8(0xC6)
-#define UDR0   UDR             /* For compatibility with previous releases. */
 
 /* LCD Control and Status Register A */
 #define LCDCRA _SFR_MEM8(0xE4)
@@ -352,12 +349,6 @@
 
 #define _VECTORS_SIZE 92
 
-/* These are to avoid breaking code compiled against old names. */
-
-#define SIG_UART0_RECV          SIG_USART_RECV 
-#define SIG_UART0_DATA          SIG_USART_DATA
-#define SIG_UART0_TRANS         SIG_USART_TRANS
-
 /* Bit numbers */
 
 /*
@@ -748,7 +739,6 @@
 
 /* WDTCR */
 #define WDCE	4
-#define WDTCE	WDCE           /* For compatibility with previous releases. */
 #define WDE	   3
 #define WDP2	2
 #define WDP1	1
@@ -898,44 +888,24 @@
 #define USICNT0 0
 
 /* UCSRA */
-#define RXC     7
-#define TXC     6
-#define UDRE    5
-#define FE      4
-#define DOR     3
-#define UPE     2
+#define RXC	7
+#define TXC	6
+#define UDRE	5
+#define FE	4
+#define DOR	3
+#define UPE 	2
 #define U2X     1
-#define MPCM    0
-
-/* UCSR0A -- For compatibility with previous releases. */
-#define RXC0    RXC
-#define TXC0    TXC
-#define UDRE0   UDRE
-#define FE0     FE
-#define DOR0    DOR
-#define UPE0    UPE
-#define U2X0    U2X
-#define MPCM0   MPCM
+#define MPCM	0
 
 /* UCSRB */
-#define RXCIE   7
-#define TXCIE   6
-#define UDRIE   5
-#define RXEN    4
-#define TXEN    3
+#define RXCIE	7
+#define TXCIE	6
+#define UDRIE	5
+#define RXEN	4
+#define TXEN	3
 #define UCSZ2   2
-#define RXB8    1
-#define TXB8    0
-
-/* UCSR0B -- For compatibility with previous releases. */
-#define RXCIE0  RXCIE
-#define TXCIE0  TXCIE
-#define UDRIE0  UDRIE
-#define RXEN0   RXEN
-#define TXEN0   TXEN
-#define UCSZ02  UCSZ2
-#define RXB80   RXB8
-#define TXB80   TXB8
+#define RXB8	1
+#define TXB8	0
 
 /* UCSRC */
 #define UMSEL   6
@@ -946,15 +916,6 @@
 #define UCSZ0   1
 #define UCPOL   0
 
-/* UCSR0C -- For compatibility with previous releases. */
-#define UMSEL0  UMSEL
-#define UPM01   UPM1
-#define UPM00   UPM0
-#define USBS0   USBS
-#define UCSZ01  UCSZ1
-#define UCSZ00  UCSZ0
-#define UCPOL0  UCPOL
-
 /* LCDCRA */
 #define LCDEN  7
 #define LCDAB  6
