@@ -6,11 +6,16 @@
 
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
+
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in
      the documentation and/or other materials provided with the
      distribution.
 
+   * Neither the name of the copyright holders nor the names of
+     contributors may be used to endorse or promote products derived
+     from this software without specific prior written permission.
+
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -23,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom64.h,v 1.6.2.2 2004/10/21 22:06:52 arcanum Exp $ */
+/* $Id: iom64.h,v 1.9 2004/11/02 18:43:56 arcanum Exp $ */
 
 /* avr/iom64.h - defines for ATmega64 
 
@@ -828,7 +833,6 @@
 #define    ADEN         7
 #define    ADSC         6
 #define    ADATE        5
-#define    ADFR         5 /* Defined for compatibility with previous releases */
 #define    ADIF         4
 #define    ADIE         3
 #define    ADPS2        2
