@@ -26,7 +26,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: pgmspace.h,v 1.16.2.5 2004/09/19 19:16:11 troth Exp $ */
+/* $Id: pgmspace.h,v 1.22.2.1 2005/01/18 16:28:05 joerg_wunsch Exp $ */
 
 /*
    pgmspace.h
@@ -495,6 +495,7 @@ extern int strcasecmp_P(const char *, PGM_P) __ATTR_PURE__;
 extern size_t strlcat_P (char *, PGM_P, size_t );
 extern size_t strlcpy_P (char *, PGM_P, size_t );
 extern size_t strlen_P(PGM_P) __ATTR_CONST__; /* program memory can't change */
+extern size_t strnlen_P(PGM_P, size_t) __ATTR_CONST__; /* program memory can't change */
 extern int strncmp_P(const char *, PGM_P, size_t) __ATTR_PURE__;
 extern int strncasecmp_P(const char *, PGM_P, size_t) __ATTR_PURE__;
 extern char *strncat_P(char *, PGM_P, size_t);
@@ -513,17 +514,4 @@ extern PGM_P strerror_P(int);
 }
 #endif
 
-/** \name Backwards compatibility macros */
-
-/*@{*/
-
-/** \ingroup avr_pgmspace
-    \def PRG_RDB
-    \deprecated
-    Use pgm_read_byte() in new programs. */
-
-#define PRG_RDB(addr)       pgm_read_byte(addr)
-
-/*@}*/
-
 #endif /* __PGMSPACE_H_ */
