@@ -1,4 +1,5 @@
-/* Copyright (c) 2002, Joerg Wunsch
+/* Copyright (c) 2002, 2005, Joerg Wunsch
+   All rights reserved.
 
    Portions of documentation Copyright (c) 1990, 1991, 1993
    The Regents of the University of California.
@@ -10,11 +11,16 @@
 
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
+
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in
      the documentation and/or other materials provided with the
      distribution.
 
+   * Neither the name of the copyright holders nor the names of
+     contributors may be used to endorse or promote products derived
+     from this software without specific prior written permission.
+
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -27,7 +33,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdio.h,v 1.11.2.4 2004/07/22 11:10:38 joerg_wunsch Exp $
+  $Id: stdio.h,v 1.16.2.1 2005/01/18 16:28:05 joerg_wunsch Exp $
 */
 
 #ifndef _STDIO_H_
@@ -207,10 +213,14 @@ struct __file;
 extern "C" {
 #endif
 
+#if !defined(DOXYGEN)
+
 extern struct __file *__iob[];
 
 extern FILE	*fdevopen(int (*__put)(char), int (*__get)(void), int __opts);
 
+#endif /* not DOXYGEN */
+
 /**
    This function closes \c stream, and disallows and further
    IO to and from it.
@@ -327,6 +337,8 @@ extern int	fclose(FILE *__stream);
            than or equal to the precision.  Trailing zeros are removed
            from the fractional part of the result; a decimal point
            appears only if it is followed by at least one digit.
+   - \c S  Similar to the \c s format, except the pointer is expected to
+           point to a program-memory (ROM) string instead of a RAM string.
 
    In no case does a non-existent or small field width cause truncation of a
    numeric field; if the result of a conversion is wider than the field
@@ -376,12 +388,16 @@ extern int	vfprintf_P(FILE *__stream, const char *__fmt, va_list __ap);
 */
 extern int	fputc(int __c, FILE *__stream);
 
+#if !defined(DOXYGEN)
+
 /* putc() function implementation, required by standard */
 extern int	putc(int __c, FILE *__stream);
 
 /* putchar() function implementation, required by standard */
 extern int	putchar(int __c);
 
+#endif /* not DOXYGEN */
+
 /**
    The macro \c putc used to be a "fast" macro implementation with a
    functionality identical to fputc().  For space constraints, in
@@ -514,12 +530,16 @@ extern size_t	fwrite(const void *__ptr, size_t __size, size_t __nmemb,
 */
 extern int	fgetc(FILE *__stream);
 
+#if !defined(DOXYGEN)
+
 /* getc() function implementation, required by standard */
 extern int	getc(FILE *__stream);
 
 /* getchar() function implementation, required by standard */
 extern int	getchar(void);
 
+#endif /* not DOXYGEN */
+
 /**
    The macro \c getc used to be a "fast" macro implementation with a
    functionality identical to fgetc().  For space constraints, in
